VerificationBox class

验证码输入框

Inheritance

Constructors

VerificationBox({int count = 6, double itemWidget = 45, ValueChanged? onSubmitted, VerificationBoxItemType type = VerificationBoxItemType.box, Decoration? decoration, double borderWidth = 2.0, double borderRadius = 5.0, TextStyle? textStyle, Color? focusBorderColor, Color? borderColor, bool unfocus = true, bool autoFocus = true, bool showCursor = false, double cursorWidth = 2, Color? cursorColor, double cursorIndent = 10, double cursorEndIndent = 10})

Properties

autoFocus → bool
是否自动获取焦点
final
borderColor → Color?
边框颜色
final
borderRadius → double
VerificationBoxItemType.box 边框圆角
final
borderWidth → double
边框宽度
final
count → int
几位验证码,一般6位,还有4位的
final
cursorColor → Color?
光标颜色
final
cursorEndIndent → double
光标距离底部距离
final
cursorIndent → double
光标距离顶部距离
final
cursorWidth → double
光标宽度
final
decoration → Decoration?
每个item的样式
final
focusBorderColor → Color?
获取焦点边框的颜色
final
hashCode → int
The hash code for this object.
no setterinherited
itemWidget → double
没一个item的宽
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSubmitted → ValueChanged?
输入完成回调
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCursor → bool
是否显示光标
final
textStyle → TextStyle?
文本样式
final
type → VerificationBoxItemType
每个item的装饰类型,VerificationBoxItemType
final
unfocus → bool
输入完成后是否失去焦点,默认true,失去焦点后,软键盘消失
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited